/**
  *  \file game/obj.cc
  *  \brief Game Object Base Classes
  *
  *  (c) 2001-2008 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/obj.h"

/*! \class GObject
    \brief Game Object

    Base class for a "physical" game object. */
GObject::~GObject()
{ }

string_t
GObject::toString()
{
    // implementation of the Object method
    return getName();
}

/** Notify all transactions. */
void
GObject::notifyTransactions()
{
    if (dirty_flags & os_Dirty) {
        dirty_flags &= ~os_Dirty;
        sig_changed.raise(getId());
    }
}

/*! \class GMapObject
    \brief Game Object on Map

    Base class for a "physical" game object on the map. */
GMapObject::~GMapObject()
{ }

/*! \class GCircularObject
    \brief Game Object on Map, with Extent

    Base class for a "physical" game object on the map, which has
    a nonzero radius (e.g. ion storm). */
GCircularObject::~GCircularObject()
{ }
