/**
  *  \file game/ufo.h
  *  \brief Ufo and Wormhole handling
  *
  *  (c) 2001-2008 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_UFO_H
#define PCC_V2_GAME_UFO_H

#include <list>
#include "game/obj.h"
#include "cpluslib/string.h"

struct TUfo;
struct TDbUfo;
struct TUtil14Wormhole;

class GUfo : public GCircularObject {
 public:
    GUfo(int id);
    GUfo(const GUfo& other);
    ~GUfo();

    GUfo& operator=(const GUfo& rhs);

    /* GCircularObject interface */
    string_t getName() const;
    string_t getFullName() const;
    int      getId() const;
    int      getOwner() const;
    bool     isExistant() const;
    GPoint   getPos() const;
    int      getRadius() const;

    /* Loader interface */
    void addUfoData(const TUfo& data);
    void addChartData(const TDbUfo& data);
    void addWormholeData(const TUtil14Wormhole& data);

    /* Accessors */
    int   getColorCode() const;
    uint8 getColor() const;
    int   getSpeed() const;
    int   getHeading() const;

    /* Values for flags */
    enum {
        UfoSeenThisTurn     = 1,
        UfoStoredInDatabase = 2
    };

 private:
    /* Standard Ufo properties */
    int16  id;
    int16  vga_color;
    GPoint pos;
    int16  warp;
    int16  heading;
    int16  planet_range, ship_range;
    int16  radius;
    int16  type_code;
    string_t name;
    string_t info1, info2;

    /* Additional PCC properties */
    int32  real_id;
    int16  turn_last_seen;
    GPoint pos_last_seen;
    GPoint movement_vector;

    int    flags;

    GPoint target;
    // reference to target Ufo?

    void copyUfo(const TUfo& data);
};

class GUfoContainer {
    typedef std::list<GUfo> ufolist_t;
    ufolist_t ufos;
 public:
    typedef ufolist_t::iterator iterator;
    typedef ufolist_t::const_iterator const_iterator;

    GUfoContainer();
    ~GUfoContainer();

    iterator begin();
    iterator end();
    const_iterator begin() const;
    const_iterator end() const;

    GUfo& getUfoById(int id);
};

inline GUfoContainer::iterator
GUfoContainer::begin()
{
    return ufos.begin();
}

inline GUfoContainer::iterator
GUfoContainer::end()
{
    return ufos.end();
}

inline GUfoContainer::const_iterator
GUfoContainer::begin() const
{
    return ufos.begin();
}

inline GUfoContainer::const_iterator
GUfoContainer::end() const
{
    return ufos.end();
}

#endif
